﻿using KTour.Common;
using KTour.Models;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Net.Http;
using System.Text;
using System.Threading.Tasks;
using System.Xml.Linq;

namespace KTour.OpenAPI
{
    public class AreaService : BaseService<CodeModel>
    {
        /// <summary>
        /// 생성자
        /// </summary>
        public AreaService() : base()
        {
            ServiceUri = "http://api.visitkorea.or.kr/openapi/service/rest/KorService/areaCode?ServiceKey={0}&MobileOS={1}&MobileApp={2}&areaCode={3}&numOfRows={4}";
        }

        /// <summary>
        /// 조회
        /// </summary>
        /// <param name="areaCode">지역코드</param>
        /// <returns></returns>
        public override async Task Send(string areaCode)
        {
            using (HttpClient hc = new HttpClient())
            {
                try
                {
                    var uri = string.Format(ServiceUri, Functions.ApiKey, Functions.MobileOS, Functions.MobileApp, areaCode, NumOfRows);
                    var result = await hc.GetStringAsync(uri);
                    if (!string.IsNullOrEmpty(result))
                    {
                        XElement xml = XElement.Parse(result);
                        var rows = from kkk in xml.Descendants("item")
                                   select new CodeModel
                                   {
                                       ParentCode = areaCode,
                                       Code = Functions.GetString(kkk.Element("code")),
                                       Name = Functions.GetString(kkk.Element("name")),
                                       ValueInt = Functions.GetInt(kkk.Element("rnum")),
                                       ValueString = "SiGunGu"
                                   };
                        ResultCollection = new ObservableCollection<CodeModel>(rows);
                    }
                }
                catch (Exception ex)
                {
                    Functions.MsgBox("오류" + ex.Message);
                }
            }
        }
    }
}
