﻿using KTour.Common;
using KTour.Models;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Net.Http;
using System.Text;
using System.Threading.Tasks;
using System.Xml.Linq;

namespace KTour.OpenAPI
{
    public class DetailCommonService : BaseService<DetailCommonModel>
    {
        public bool IsBusy { get; set; }

        public DetailCommonService()
        {
            ServiceUri = "http://api.visitkorea.or.kr/openapi/service/rest/KorService/detailCommon?ServiceKey={0}&contentId={1}&contentTypeId={2}&defaultYN=Y&firstImageYN=Y&areacodeYN=Y&catcodeYN=Y&addrinfoYN=Y&mapinfoYN=Y&overviewYN=Y&transGuideYN=Y&MobileOS={3}&MobileApp={4}";
            IsBusy = false;
        }

        public override async Task Send(string para)
        {
            if (IsBusy == true) return;
            IsBusy = true;

            var split = para.Split('|');
            if (split.Count() < 2) return;

            using (HttpClient hc = new HttpClient())
            {
                try
                {
                    var uri = string.Format(ServiceUri, Functions.ApiKey, split[0], split[1], Functions.MobileOS, Functions.MobileApp);
                    var result = await hc.GetStringAsync(uri);
                    if (!string.IsNullOrEmpty(result))
                    {
                        XElement xml = XElement.Parse(result);

                        var header = xml.Element("header");
                        ResultCode = Functions.GetInt(header.Element("resultCode")).ToString();
                        ResultMsg = Functions.GetString(header.Element("resultMsg"));

                        switch (ResultCode)
                        {
                            case "0":   //정상
                                var rows = from kkk in xml.Descendants("item")
                                           select new DetailCommonModel
                                           {
                                               ContentId = Functions.GetString(kkk.Element("contentid")),
                                               ContentTypeId = Functions.GetString(kkk.Element("contenttypeid")),
                                               CreateTime = Functions.GetString(kkk.Element("createdtime")),
                                               ModifiedTime = Functions.GetString(kkk.Element("modifiedtime")),
                                               HomePage = Functions.GetString(kkk.Element("homepage")),
                                               BookTour = Functions.GetString(kkk.Element("booktour")),
                                               Tel = Functions.GetString(kkk.Element("tel")),
                                               TelName = Functions.GetString(kkk.Element("telname")),
                                               FirstImage = new Uri(Functions.GetString(kkk.Element("firstimage"))),
                                               FirstImage2 = new Uri(Functions.GetString(kkk.Element("firstimage2"))),
                                               AreaCode = Functions.GetString(kkk.Element("areacode")),
                                               SiGunGuCode = Functions.GetString(kkk.Element("sigungucode")),
                                               Cat1 = Functions.GetString(kkk.Element("cat1")),
                                               Cat2 = Functions.GetString(kkk.Element("cat2")),
                                               Cat3 = Functions.GetString(kkk.Element("cat3")),
                                               Addr1 = Functions.GetString(kkk.Element("addr1")),
                                               Addr2 = Functions.GetString(kkk.Element("addr2")),
                                               ZipCode = Functions.GetString(kkk.Element("zipcode")),
                                               MapX = Functions.GetString(kkk.Element("mapx")),
                                               MapY = Functions.GetString(kkk.Element("mapy")),
                                               MLevel = Functions.GetString(kkk.Element("mlevel")),
                                               Overview = Functions.GetString(kkk.Element("overview")),
                                               WayGuide = Functions.GetString(kkk.Element("wayguide")),
                                               InsideArea = Functions.GetString(kkk.Element("insidearea")),
                                               InterArea = Functions.GetString(kkk.Element("interarea")),
                                               Shuttle = Functions.GetString(kkk.Element("shuttle"))
                                           };
                                ResultCollection = new System.Collections.ObjectModel.ObservableCollection<DetailCommonModel>(rows);
                                break;
                            case "22":  //서비스 요청제한횟수 초과에러
                                break;
                            default:
                                Functions.MsgBox("조회 중 오류가 발생했습니다.\n" + ResultMsg);
                                ResultCollection.Clear();
                                break;
                        }

                    }
                }
                catch (Exception ex)
                {
                    Functions.MsgBox("오류" + ex.Message);
                }

                IsBusy = false;
            }            
        }
    }
}
