﻿using KTour.Models;
using KTour.OpenAPI;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using WinRTDatabase;

namespace KTour.ViewModels
{
    public class DatabaseViewModel : KTour.Common.BindableBase
    {
        private string DatabaseName = "KTourDb";
        private Database _database;

        /// <summary>
        /// 코드 마스터
        /// </summary>
        public Table<CodeModel> CodeMST { get; set; }

        public DatabaseViewModel()
        {
            if (Windows.ApplicationModel.DesignMode.DesignModeEnabled)
            {
                //디자인 타임
            }
            else
            {
            }
        }

        public async Task Initialise()
        {
            var exists = await Database.DoesDatabaseExistsAsync(DatabaseName, StorageLocation.Local);
            if (!exists)
            {
                _database = await Database.CreateDatabaseAsync(DatabaseName, StorageLocation.Local);
                _database.CreateTable<CodeModel>();
                await _database.SaveAsync();
            }
            else
            {
                _database = await Database.OpenDatabaseAsync(DatabaseName, true, StorageLocation.Local);
            }

            CodeMST = await _database.Table<CodeModel>();
            if (CodeMST.Count == 0)
            {
                AddHead();
                AddAreaS();
                AddCategoryS();
            }
        }

        private async void AddHead()
        {
            CodeMST.Add(new CodeModel { Code = "ContentType", Name = "관광정보타입코드" });
            CodeMST.Add(new CodeModel { ParentCode = "ContentType", Code="12", Name = "관광지", ValueString = "국문"});
            CodeMST.Add(new CodeModel { ParentCode = "ContentType", Code="14", Name = "문화시설", ValueString = "국문"});
            CodeMST.Add(new CodeModel { ParentCode = "ContentType", Code="15", Name = "행사/공연/축제", ValueString = "국문"});
            CodeMST.Add(new CodeModel { ParentCode = "ContentType", Code="25", Name = "여행코스", ValueString = "국문"});
            CodeMST.Add(new CodeModel { ParentCode = "ContentType", Code="28", Name = "레포츠", ValueString = "국문"});
            CodeMST.Add(new CodeModel { ParentCode = "ContentType", Code="32", Name = "숙박", ValueString = "국문"});
            CodeMST.Add(new CodeModel { ParentCode = "ContentType", Code="38", Name = "쇼핑", ValueString = "국문"});
            CodeMST.Add(new CodeModel { ParentCode = "ContentType", Code="39", Name = "음식점", ValueString = "국문"});
            CodeMST.Add(new CodeModel { ParentCode = "ContentType", Code="40", Name = "교통시설", ValueString = "국문"});

            CodeMST.Add(new CodeModel { Code = "Area", Name = "지역코드" });
            CodeMST.Add(new CodeModel { ParentCode = "Area", Code = "1", Name = "서울", ValueInt = 1, ValueString = "Area"});
            CodeMST.Add(new CodeModel { ParentCode = "Area", Code = "2", Name = "인천", ValueInt = 2, ValueString = "Area" });
            CodeMST.Add(new CodeModel { ParentCode = "Area", Code = "3", Name = "대전", ValueInt = 3, ValueString = "Area" });
            CodeMST.Add(new CodeModel { ParentCode = "Area", Code = "4", Name = "대구", ValueInt = 4, ValueString = "Area" });
            CodeMST.Add(new CodeModel { ParentCode = "Area", Code = "5", Name = "광주", ValueInt = 5, ValueString = "Area" });
            CodeMST.Add(new CodeModel { ParentCode = "Area", Code = "6", Name = "부산", ValueInt = 6, ValueString = "Area" });
            CodeMST.Add(new CodeModel { ParentCode = "Area", Code = "7", Name = "울산", ValueInt = 7, ValueString = "Area" });
            CodeMST.Add(new CodeModel { ParentCode = "Area", Code = "8", Name = "세종특별자치시", ValueInt = 8, ValueString = "Area" });
            CodeMST.Add(new CodeModel { ParentCode = "Area", Code = "31", Name = "경기도", ValueInt = 31, ValueString = "Area" });
            CodeMST.Add(new CodeModel { ParentCode = "Area", Code = "32", Name = "강원도", ValueInt = 32, ValueString = "Area" });
            CodeMST.Add(new CodeModel { ParentCode = "Area", Code = "33", Name = "충청북도", ValueInt = 33, ValueString = "Area" });
            CodeMST.Add(new CodeModel { ParentCode = "Area", Code = "34", Name = "충청남도", ValueInt = 34, ValueString = "Area" });
            CodeMST.Add(new CodeModel { ParentCode = "Area", Code = "35", Name = "경상북도", ValueInt = 35, ValueString = "Area" });
            CodeMST.Add(new CodeModel { ParentCode = "Area", Code = "36", Name = "경상남도", ValueInt = 36, ValueString = "Area" });
            CodeMST.Add(new CodeModel { ParentCode = "Area", Code = "37", Name = "전라북도", ValueInt = 37, ValueString = "Area" });
            CodeMST.Add(new CodeModel { ParentCode = "Area", Code = "38", Name = "전라남도", ValueInt = 38, ValueString = "Area" });
            CodeMST.Add(new CodeModel { ParentCode = "Area", Code = "39", Name = "제주도", ValueInt = 39, ValueString = "Area" });

            CodeMST.Add(new CodeModel { Code = "CategoryCode", Name = "서비스분류코드" });
            CodeMST.Add(new CodeModel { ParentCode = "CategoryCode", Code = "A01", Name = "자연", ValueInt = 1, ValueString = "CategoryCode" });
            CodeMST.Add(new CodeModel { ParentCode = "CategoryCode", Code = "A02", Name = "인문(문화/예술/역사)", ValueInt = 2, ValueString = "CategoryCode" });
            CodeMST.Add(new CodeModel { ParentCode = "CategoryCode", Code = "A03", Name = "레포츠", ValueInt = 3, ValueString = "CategoryCode" });
            CodeMST.Add(new CodeModel { ParentCode = "CategoryCode", Code = "A04", Name = "쇼핑", ValueInt = 4, ValueString = "CategoryCode" });
            CodeMST.Add(new CodeModel { ParentCode = "CategoryCode", Code = "A05", Name = "음식", ValueInt = 5, ValueString = "CategoryCode" });
            CodeMST.Add(new CodeModel { ParentCode = "CategoryCode", Code = "B01", Name = "교통", ValueInt = 6, ValueString = "CategoryCode" });
            CodeMST.Add(new CodeModel { ParentCode = "CategoryCode", Code = "B02", Name = "숙박", ValueInt = 7, ValueString = "CategoryCode" });
            CodeMST.Add(new CodeModel { ParentCode = "CategoryCode", Code = "C01", Name = "추천코스", ValueInt = 8, ValueString = "CategoryCode" });

            await _database.SaveAsync();
        }

        /// <summary>
        /// Area Service를 이용해서 각 지역별 시군구 코드를 db에 저장한다.
        /// </summary>
        private async void AddAreaS()
        {
            var AreaS = new AreaService();
            var areas = CodeMST.Where(p => p.ParentCode == "Area").ToList();
            foreach (var item in areas)
            {
                await AreaS.Send(item.Code);
                foreach (var code in AreaS.ResultCollection)
                {
                    CodeMST.Add(code);
                }
            }
            await _database.SaveAsync();
        }

        /// <summary>
        /// Category Servie를 이용해서 각 카테고리 코드를 db에 저장한다.
        /// </summary>
        private async void AddCategoryS()
        {
            var CateS = new CategoryService();
            var cates = CodeMST.Where(p => p.ParentCode == "CategoryCode").ToList();
            foreach (var first in cates)
            {
                await CateS.Send(first.Code);
                var seconds = CateS.ResultCollection.ToList();
                foreach (var second in seconds)
                {
                    CodeMST.Add(second);
                    await CateS.Send(first.Code + "|" + second.Code);
                    foreach (var third in CateS.ResultCollection)
                    {
                        CodeMST.Add(third);
                    }
                }
            }
            await _database.SaveAsync();
        }
    }
}
