﻿using KTour.Common;
using KTour.Models;
using KTour.Selectors;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Data;
using Windows.UI.Xaml.Documents;

namespace KTour.ViewModels
{
    public class DetailViewModel : KTour.Common.BindableBase
    {
        public string ContentId { get; set; }

        public string ContentTypeId { get; set; }

        private DetailCommonModel detailCommon;
        /// <summary>
        /// 기본 정보
        /// </summary>
        public DetailCommonModel DetailCommon
        {
            get { return detailCommon; }
            set 
            { 
                detailCommon = value;
                OnPropertyChanged();
            }
        }

        private DetailSelector selector;
        /// <summary>
        /// 아이템템플릿 셀렉터
        /// </summary>
        public DetailSelector Selector
        {
            get { return selector; }
            set 
            { 
                selector = value;
                OnPropertyChanged();
            }
        }

        private ObservableCollection<GroupModel<CodeModel>> groupCollection;
        /// <summary>
        /// 그룹 컬렉션
        /// </summary>
        public ObservableCollection<GroupModel<CodeModel>> GroupCollection
        {
            get { return groupCollection; }
            set
            {
                groupCollection = value;
                OnPropertyChanged();
            }
        }

        private CollectionViewSource viewSource;
        /// <summary>
        /// 컬렉션 뷰
        /// </summary>
        public ICollectionView View
        {
            get
            {
                if (viewSource == null)
                {
                    viewSource = new CollectionViewSource();
                    viewSource.Source = GroupCollection;
                    viewSource.IsSourceGrouped = true;
                    viewSource.ItemsPath = new Windows.UI.Xaml.PropertyPath("Items");
                }
                return viewSource.View;
            }
        }

        public DetailViewModel()
        {
            Selector = new DetailSelector 
                {
                    TextTemplate = App.Current.Resources["DetailIntroItemTemplate"] as DataTemplate,
                    PictureTemplate = App.Current.Resources["DetailPictureItemTemplate"] as DataTemplate,
                    MapTemplate = App.Current.Resources["DetailIntroItemTemplate"] as DataTemplate,
                };

            if (Windows.ApplicationModel.DesignMode.DesignModeEnabled)
            {
                DetailCommon = new DetailCommonModel
                {
                    ContentId = "1773871",
                    ContentTypeId = "15",
                    CreateTime = "20130102135037",
                    FirstImage = new Uri("http://tong.visitkorea.or.kr/cms/resource/08/1785108_image2_1.jpg"),
                    FirstImage2 = new Uri("http://tong.visitkorea.or.kr/cms/resource/08/1785108_image2_1.jpg"),
                    HomePage = "<a href=\"http://cpfestival.kr\" target=\"_blank\" title=\"청평눈썰매빙어축제 홈페이지로 이동\">http://cpfestival.kr</a>",
                    ModifiedTime = "modifiedtime",
                    Overview = "2013년 제1회를 맞이하는 '청평눈썰매빙어축제'는 무엇보다 저렴한 가격과 놀이시설로 관광객들이 부담없이 찾아 즐길 수 있으면 하는 마음으로 시작된 축제이다. 청평 눈썰매 빙어 축제장은 에코피아를 실천하는 북한강 자락의 청정 지역이다. 서울 춘간 전철과 춘천 고속도로로 인하여 30분대에 올 수 있으며 그 어느 곳 보다도 가까운 곳에 위치해 있어 접근성이 용이하다. 아름다운 산과 호수 그리고 북한강이 흐르는 고장 청평을 찾아주셔서 다채로운 겨울추억을 듬뿍 담아가시길 바란다.",
                    Title = "청평눈썰매빙어축제 2013"
                };

                GroupCollection = new ObservableCollection<GroupModel<CodeModel>>
                {
                    new GroupModel<CodeModel>
                        { 
                            GroupCode = "1", 
                            GroupName = "소개",
                            Items = new Common.CommonILC<CodeModel>()
                                { 
                                    new CodeModel
                                        {
                                            Code = "1",
                                            ValueString = "<div><p><b>주최/주관</b></p><p>청평1리 청장년회, 청평눈썰매빙어축제 위원회/ Tel. 031-584-5909</p></div> <div><p><b>행사소개</b></p><p>2013년 제1회를 맞이하는 '청평눈썰매빙어축제'는 무엇보다 저렴한 가격과 놀이시설로 관광객들이 부담없이 찾아 즐길 수 있으면 하는 마음으로 시작된 축제이다. 청평 눈썰매 빙어 축제장은 에코피아를 실천하는 북한강 자락의 청정 지역이다. 서울 춘간 전철과 춘천 고속도로로 인하여 30분대에 올 수 있으며 그 어느 곳 보다도 가까운 곳에 위치해 있어 접근성이 용이하다. 아름다운 산과 호수 그리고 북한강이 흐르는 고장 청평을 찾아주셔서 다채로운 겨울추억을 듬뿍 담아가시길 바란다.</p></div> <div><p><b>행사내용</b></p><p>[축제 즐길거리] 빙어낚시 눈썰매 얼음썰매 (전통썰매) 사륜오토바이크 팽이치기 등 다양한 프로그램 및 부대시설</p></div> <div><p><b>행사소개</b></p><p>2013년 제1회를 맞이하는 '청평눈썰매빙어축제'는 무엇보다 저렴한 가격과 놀이시설로 관광객들이 부담없이 찾아 즐길 수 있으면 하는 마음으로 시작된 축제이다. 청평 눈썰매 빙어 축제장은 에코피아를 실천하는 북한강 자락의 청정 지역이다. 서울 춘간 전철과 춘천 고속도로로 인하여 30분대에 올 수 있으며 그 어느 곳 보다도 가까운 곳에 위치해 있어 접근성이 용이하다. 아름다운 산과 호수 그리고 북한강이 흐르는 고장 청평을 찾아주셔서 다채로운 겨울추억을 듬뿍 담아가시길 바란다.</p></div>"
                                        } 
                                }
                        },

                    new GroupModel<CodeModel>
                        {
                            GroupCode = "2",
                            GroupName = "사진",
                            Items = new Common.CommonILC<CodeModel>
                                {
                                    new CodeModel { Code = "2", Name = "사진셈플1", ValueString = "http://tong.visitkorea.or.kr/cms/resource/09/1785109_image2_1.jpg"},
                                    new CodeModel { Code = "2", Name = "사진셈플2", ValueString = "http://tong.visitkorea.or.kr/cms/resource/11/1785111_image2_1.jpg"},
                                    new CodeModel { Code = "2", Name = "사진셈플3", ValueString = "http://tong.visitkorea.or.kr/cms/resource/12/1785112_image2_1.jpg"},
                                    new CodeModel { Code = "2", Name = "사진셈플4", ValueString = "http://tong.visitkorea.or.kr/cms/resource/24/1785124_image2_1.jpg"},
                                    new CodeModel { Code = "2", Name = "사진셈플5", ValueString = "http://tong.visitkorea.or.kr/cms/resource/26/1785126_image2_1.jpg"},
                                }
                        },
                };
            }
            else
            {
                GroupCollection = new ObservableCollection<GroupModel<CodeModel>>();
            }
        }

        public async void Init(string para)
        {
            var split = para.Split('|');
            ContentId = split[0];
            ContentTypeId = split[1];
            //서비스에서 타이틀이 없는 경우가 있음..그래서 보내는 곳에서 타이틀 입력해서 보내줘야함
            var title = split[2];

            KTour.OpenAPI.DetailCommonService DetailCommonS = new OpenAPI.DetailCommonService();
            await DetailCommonS.Send(para);
            DetailCommon = DetailCommonS.ResultCollection.FirstOrDefault();
            DetailCommon.Title = title;

            var group = new GroupModel<CodeModel> 
                {
                    GroupCode = "1",
                    GroupName = "소개",
                    Items = new CommonILC<CodeModel>()
                };

            StringBuilder sb = new StringBuilder();
            sb.AppendLine(GetHtml("행사소개", DetailCommon.Overview));
            sb.AppendLine(GetHtml("주소", DetailCommon.Addr1 + DetailCommon.Addr2));
            group.Items.Add(new CodeModel { Code = "1", ValueString = sb.ToString() });

            System.Diagnostics.Debug.WriteLine("Init : " + para.ToString());
            GroupCollection.Add(group);
        }

        private string GetHtml(string Head, string Body)
        {
            string returnValue = string.Format("<div><p><b>{0}</b></p><p>{1}</p></div>", Head, Body);
            return returnValue;
        }
    }
}
