﻿using KTour.Common;
using KTour.Models;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Data;

namespace KTour.ViewModels
{
    public class FestivalViewModel : KTour.Common.BindableBase
    {
        /// <summary>
        /// 행사 정보 조회 서비스
        /// </summary>
        public KTour.OpenAPI.FestivalService FestivalS { get; set; }

        private KTour.Selectors.MoreDataSelector selector;
        /// <summary>
        /// 아이템 템플릿 셀렉터
        /// </summary>
        public KTour.Selectors.MoreDataSelector Selector 
        {
            get { return selector; }
            set 
            {
                selector = value;
                OnPropertyChanged();
            }
        }        

        private ObservableCollection<GroupModel<FestivalModel>> groupCollection;
        /// <summary>
        /// 그룹 컬렉션
        /// </summary>
        public ObservableCollection<GroupModel<FestivalModel>> GroupCollection
        {
            get { return groupCollection; }
            set 
            { 
                groupCollection = value;
                OnPropertyChanged();
            }
        }

        private CollectionViewSource viewSource;
        /// <summary>
        /// 컬렉션 뷰
        /// </summary>
        public ICollectionView View 
        {
            get
            {
                if (viewSource == null)
                {
                    viewSource = new CollectionViewSource();
                    viewSource.Source = GroupCollection;
                    viewSource.IsSourceGrouped = true;
                    viewSource.ItemsPath = new Windows.UI.Xaml.PropertyPath("Items");
                }
                return viewSource.View;
            }
        }

        /// <summary>
        /// 생성자
        /// </summary>
        public FestivalViewModel()
        {
            FestivalS = new OpenAPI.FestivalService();
            GroupCollection = new ObservableCollection<GroupModel<FestivalModel>>();

            if (!Windows.ApplicationModel.DesignMode.DesignModeEnabled)
            {
            }
            else
            {
                var ilc = new Common.CommonILC<FestivalModel>();
                foreach (var item in Design.DesignData.FestivalCollection())
                {
                    ilc.Add(item);
                }
                GroupCollection.Add(new GroupModel<FestivalModel> { GroupName = "인기 행사", Items = ilc });
                GroupCollection.Add(new GroupModel<FestivalModel> { GroupName = "최신 행사", Items = ilc });

                Selector = new Selectors.MoreDataSelector
                {
                    DefaultTemplate = App.Current.Resources["FestivallItemTemplate"] as DataTemplate,
                    MoreDataTemplate = App.Current.Resources["MoreFestivallItemTemplate"] as DataTemplate
                };
            }
        }

        public async Task Init()
        {
            var locator = App.Current.Resources["Locator"] as KTour.ViewModels.ViewModelLocator;

            if (Selector == null)
            {
                Selector = new Selectors.MoreDataSelector 
                    {
                        DefaultTemplate = App.Current.Resources["FestivallItemTemplate"] as DataTemplate,
                        MoreDataTemplate = App.Current.Resources["MoreFestivallItemTemplate"] as DataTemplate
                    };
            }

            if (GroupCollection.Count == 0)
            {
                //인기행사
                FestivalS.Arrange = "B";
                FestivalS.NumOfRows = 7;
                FestivalS.PageNo = 1;
                await FestivalS.Send(DateTime.Now.ToString("yyyyMMdd"));

                var ilc = new Common.CommonILC<FestivalModel>();
                foreach (var item in FestivalS.ResultCollection)
                {
                    ilc.Add(item);
                }
                if (FestivalS.TotalPage > FestivalS.PageNo)
                {
                    ilc.Add(new FestivalModel { ContentId = "MoreData", Title = string.Format("{0} / {1}", FestivalS.PageNo, FestivalS.TotalPage), Cat1 = FestivalS.Arrange, Cat2 = (FestivalS.NumOfRows + 1).ToString(), Cat3 = (FestivalS.PageNo + 1).ToString() });
                }
                GroupCollection.Add(new GroupModel<FestivalModel> { GroupCode = "B", GroupName = "인기 행사", Items = ilc });

                //최신행사
                FestivalS.Arrange = "C";
                FestivalS.NumOfRows = 19;
                FestivalS.PageNo = 1;
                await FestivalS.Send(DateTime.Now.ToString("yyyyMMdd"));

                ilc = new Common.CommonILC<FestivalModel>();
                foreach (var item in FestivalS.ResultCollection)
                {
                    ilc.Add(item);
                }
                if (FestivalS.TotalPage > FestivalS.PageNo)
                {
                    ilc.Add(new FestivalModel { ContentId = "MoreData", Title = string.Format("{0} / {1}", FestivalS.PageNo, FestivalS.TotalPage), Cat1 = FestivalS.Arrange, Cat2 = (FestivalS.NumOfRows + 1).ToString(), Cat3 = (FestivalS.PageNo + 1).ToString() });
                }
                GroupCollection.Add(new GroupModel<FestivalModel> { GroupCode = "C", GroupName = "최신 행사", Items = ilc });
            }
        }

        public async void ItemClick(object item)
        {
            var fm = item as FestivalModel;
            if (fm != null)
            {
                if (fm.ContentId == "MoreData")
                {
                    FestivalS.Arrange = fm.Cat1;
                    FestivalS.NumOfRows = Convert.ToInt32(fm.Cat2);
                    FestivalS.PageNo = Convert.ToInt32(fm.Cat3);
                    await FestivalS.Send(null);

                    var group = GroupCollection.FirstOrDefault(p => p.GroupCode == fm.Cat1);
                    //MoreData 삭제
                    group.Items.RemoveAt(group.Items.Count - 1);
                    //새데이터 입력
                    foreach (var i in FestivalS.ResultCollection)
                    {
                        group.Items.Add(i);
                    }
                    //MoreData 추가
                    if (FestivalS.TotalPage > FestivalS.PageNo)
                    {
                        group.Items.Add(new FestivalModel { ContentId = "MoreData", Title = string.Format("{0} / {1}", FestivalS.PageNo, FestivalS.TotalPage), Cat1 = FestivalS.Arrange, Cat2 = FestivalS.NumOfRows.ToString(), Cat3 = (FestivalS.PageNo + 1).ToString() });
                    }
                }
                else
                { 
                    //상세보기 페이지로 네비게이트
                    Functions.NavigationPage(typeof(KTour.Views.DetailView), fm.ContentId + "|" + fm.ContentTypeId + "|" + fm.Title);
                }
            }
        }

        private DelegateCommand searchCommand;
        /// <summary>
        /// 검색 커맨드
        /// </summary>
        public DelegateCommand SearchCommand
        {
            get 
            {
                if (searchCommand == null)
                {
                    searchCommand = new DelegateCommand(
                        args => 
                        {
                            var popup = Functions.OpenPopupElement(typeof(KTour.UserControls.FestivalUC), args as FrameworkElement);
                            popup.Closed += 
                                async (s, e) => 
                                {
                                    var locator = App.Current.Resources["Locator"] as KTour.ViewModels.ViewModelLocator;
                                    if (locator.FestivalUCVM.SelectedItem != null)
                                    {
                                        //검색해서 결과 출력
                                        FestivalS.Arrange = "A";
                                        FestivalS.NumOfRows = 19;
                                        FestivalS.PageNo = 1;
                                        await FestivalS.Send(locator.FestivalUCVM.SelectedItem.ValueString);

                                        var rg = GroupCollection.FirstOrDefault(p => p.GroupCode == "A");
                                        if (rg != null)
                                        {
                                            GroupCollection.Remove(rg);
                                        }

                                        var ilc = new Common.CommonILC<FestivalModel>();
                                        foreach (var item in FestivalS.ResultCollection.OrderByDescending(p => p.EventStartDate))
                                        {
                                            ilc.Add(item);
                                        }
                                        if (FestivalS.TotalPage > FestivalS.PageNo)
                                        {
                                            ilc.Add(new FestivalModel { ContentId = "MoreData", Title = string.Format("{0} / {1}", FestivalS.PageNo, FestivalS.TotalPage), Cat1 = FestivalS.Arrange, Cat2 = (FestivalS.NumOfRows + 1).ToString(), Cat3 = (FestivalS.PageNo + 1).ToString() });
                                        }
                                        GroupCollection.Insert( 0, new GroupModel<FestivalModel> { GroupCode = FestivalS.Arrange, GroupName = locator.FestivalUCVM.SelectedItem.Name + " 행사", Items = ilc });
                                    }
                                    else
                                    { 
                                        //그룹컬렉션에서 검색 결과 삭제
                                        var removeGroups = GroupCollection.Where(p => p.GroupCode == "A").ToList();
                                        foreach (var item in removeGroups)
                                        {
                                            GroupCollection.Remove(item);
                                        }
                                    }
                                };
                        });
                }
                return searchCommand; 
            }
        }

    }
}
