﻿using System;
using System.Threading.Tasks;
using Windows.System;
using Windows.ApplicationModel.Activation;
using Windows.Foundation;
using Windows.UI.Core;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Data;
using Windows.UI.Xaml.Navigation;
using Windows.UI.ApplicationSettings;
using Windows.UI.Popups;
using Windows.UI.Xaml.Controls.Primitives;
using Windows.UI.Xaml.Media.Animation;
using KTour.ViewModels;

namespace KTour.Views
{
    /// <summary>
    /// 페이지나 유저컨트롤이 아닌 Grid 한개임
    /// </summary>
    partial class ExtendedSplash
    {
        internal Rect splashImageRect; // Rect to store splash screen image coordinates.
        internal bool dismissed = false; // Variable to track splash screen dismissal status.

        // Used to determine the correct height to ensure our custom UI fills the screen.
        private Rect windowBounds;

        private SplashScreen splash; // Variable to hold the splash screen object.

        private int settingsWidth= 345;
        double popupWidth = 346;
        Popup aboutPopup;

        public ExtendedSplashViewModel ViewModel
        {
            get { return this.DataContext as ExtendedSplashViewModel; }
            set
            {
                this.DataContext = value;
            }
        }

        public ExtendedSplash(SplashScreen splashscreen, bool loadState)
        {
            this.InitializeComponent();

            if (!Windows.ApplicationModel.DesignMode.DesignModeEnabled)
            {
                ViewModel = new ExtendedSplashViewModel();
            }
            
            //스플레쉬스크린
            splash = splashscreen;
            if (splash != null)
            {
                // Register an event handler to be executed when the splash screen has been dismissed.
                splash.Dismissed += new TypedEventHandler<SplashScreen, Object>(DismissedEventHandler);

                // Retrieve the window coordinates of the splash screen image.
                splashImageRect = splash.ImageLocation;
                PositionImage();
            }

            Window.Current.SizeChanged += Current_SizeChanged;

            // Restore the saved session state if necessary
            ViewModel.Init(loadState);

            //App settings - 설정참
            windowBounds = Window.Current.Bounds;
            SettingsPane.GetForCurrentView().CommandsRequested += onCommandsRequested;
        }

        void Current_SizeChanged(object sender, WindowSizeChangedEventArgs e)
        {
            // Safely update the extended splash screen image coordinates. This function will be fired in response to snapping, unsnapping, rotation, etc...
            if (splash != null)
            {
                // Update the coordinates of the splash screen image.
                splashImageRect = splash.ImageLocation;
                PositionImage();
            }            
        }

        // Include code to be executed when the system has transitioned from the splash screen to the extended splash screen (application's first view).
        void DismissedEventHandler(SplashScreen sender, object e)
        {
            dismissed = true;
            // Navigate away from the app's extended splash screen after completing setup operations here...
            // This sample navigates away from the extended splash screen when the "Learn More" button is clicked.
        }

        // Position the extended splash screen image in the same location as the system splash screen image.
        void PositionImage()
        {
            extendedSplashImage.SetValue(Canvas.LeftProperty, splashImageRect.X);
            extendedSplashImage.SetValue(Canvas.TopProperty, splashImageRect.Y);
            extendedSplashImage.Height = splashImageRect.Height;
            extendedSplashImage.Width = splashImageRect.Width;
        }


        /// <summary>
        /// This event is generated when the user opens the settings pane. During this event, append your
        /// SettingsCommand objects to the available ApplicationCommands vector to make them available to the
        /// SettingsPange UI.
        /// </summary>
        /// <param name="settingsPane">Instance that triggered the event.</param>
        /// <param name="eventArgs">Event data describing the conditions that led to the event.</param>
        void onCommandsRequested(SettingsPane settingsPane, SettingsPaneCommandsRequestedEventArgs args)
        {
            //SettingsCommand helpCommand = new SettingsCommand("helpPage", "도움말",
            //    async handler =>
            //    {
            //        await Launcher.LaunchUriAsync(new Uri("http://kaki104.tistory.com/158", UriKind.Absolute));
            //    });
            //args.Request.ApplicationCommands.Add(helpCommand);

            ////SettingsCommand appInfoCommand = new SettingsCommand("appInfoPage", "정보", new UICommandInvokedHandler(onCommand));
            //var bounds = Windows.UI.Xaml.Window.Current.CoreWindow.Bounds;
            //SettingsCommand cmd = new SettingsCommand("About", "정보", _ =>
            //{
            //    aboutPopup = new Popup();
            //    aboutPopup.Closed += OnPopupClosed;
            //    Window.Current.Activated += OnWindowActivated;
            //    aboutPopup.IsLightDismissEnabled = true;
            //    aboutPopup.Width = popupWidth;
            //    aboutPopup.Height = bounds.Height;

            //    AboutSettingView aboutSettingView = new AboutSettingView();
            //    aboutSettingView.Width = popupWidth;
            //    aboutSettingView.Height = bounds.Height;

            //    aboutPopup.Child = aboutSettingView;
            //    aboutPopup.SetValue(Canvas.LeftProperty, bounds.Width - popupWidth);
            //    aboutPopup.SetValue(Canvas.TopProperty, 0);
            //    aboutPopup.IsOpen = true;
            //});

            //args.Request.ApplicationCommands.Add(cmd);

            //SettingsCommand privateCommand = new SettingsCommand("privatePage", "개인정보 보호정책",
            //    async handler =>
            //    {
            //        await Launcher.LaunchUriAsync(new Uri("http://kaki104.tistory.com/entry/개인정보-보호-정책-안내", UriKind.Absolute));
            //    });
            //args.Request.ApplicationCommands.Add(privateCommand);
        }

        void OnPopupClosed(object sender, object e)
        {
            Window.Current.Activated -= OnWindowActivated;
        }

        private void OnWindowActivated(object sender, Windows.UI.Core.WindowActivatedEventArgs e)
        {
            if (e.WindowActivationState == Windows.UI.Core.CoreWindowActivationState.Deactivated)
            {
                if (aboutPopup != null)
                {
                    aboutPopup.IsOpen = false;
                }
            }
        }

    }
}
